@@ -1,13 +1,15 @@
-context("test default methods for nice error messages")
-
 test_that("test default corpus* methods", {
     expect_error(
         corpus(TRUE),
         "corpus\\(\\) only works on.*character.*corpus.*objects"
     )
+    expect_error(
+        corpus_group(TRUE),
+        "corpus_group\\(\\) only works on corpus objects"
+    )
     expect_error(
         as.corpus(c(1, 2, 3)),
-        "as.corpus\\(\\) only works on.*corpuszip"
+        "as.corpus\\(\\) only works on corpus objects"
     )
     expect_error(
         corpus_reshape(1),
@@ -36,18 +38,10 @@ test_that("test detault n-methods", {
         nfeat(TRUE),
         "nfeat\\(\\) only works on dfm.*objects"
     )
-    expect_error(
-        nscrabble(TRUE),
-        "nscrabble\\(\\) only works on character.*objects"
-    )
     expect_error(
         nsentence(TRUE),
         "nsentence\\(\\) only works on.*corpus.*tokens objects"
     )
-    expect_error(
-        nsyllable(TRUE),
-        "nsyllable\\(\\) only works on character, tokens objects"
-    )
     expect_error(
         ntoken(TRUE),
         "ntoken\\(\\) only works on character.*tokens objects"
@@ -92,11 +86,11 @@ test_that("test detault fcm* methods", {
     )
     expect_error(
         fcm_keep(1),
-        "fcm_keep\\(\\) only works on fcm objects"
+        "fcm_select\\(\\) only works on fcm objects"
     )
     expect_error(
         fcm_remove(1),
-        "fcm_remove\\(\\) only works on fcm objects"
+        "fcm_select\\(\\) only works on fcm objects"
     )
     expect_error(
         fcm_select(1),
@@ -127,18 +121,6 @@ test_that("test default docvars methods", {
     )
 })
 
-test_that("test default metadoc methods", {
-    expect_error(
-        metadoc(0),
-        "metadoc\\(\\) only works on.*corpus.*tokens objects"
-    )
-    expect_error(
-        metadoc(data_char_sampletext) <- "X",
-        "metadoc<-() only works on corpus, dfm, tokens objects.",
-        fixed = TRUE
-    )
-})
-
 test_that("kwic default works", {
     expect_error(
         kwic(TRUE),
@@ -195,6 +177,10 @@ test_that("test new dfm methods", {
         dfm_keep(TRUE),
         "dfm_select\\(\\) only works on dfm objects"
     )
+    expect_error(
+        dfm_match(TRUE),
+        "dfm_match\\(\\) only works on dfm objects"
+    )
     expect_error(
         dfm_lookup(TRUE),
         "dfm_lookup\\(\\) only works on dfm objects"
@@ -207,6 +193,10 @@ test_that("test new dfm methods", {
         dfm_sample(TRUE),
         "dfm_sample\\(\\) only works on dfm objects"
     )
+    expect_error(
+        dfm_replace(TRUE),
+        "dfm_replace\\(\\) only works on dfm objects"
+    )
     expect_error(
         dfm_select(TRUE),
         "dfm_select\\(\\) only works on dfm objects"
@@ -262,10 +252,22 @@ test_that("test token default methods", {
         tokens(TRUE),
         "tokens\\(\\) only works on character, corpus, list, tokens objects"
     )
+    expect_error(
+        tokens_group(TRUE),
+        "tokens_group\\(\\) only works on tokens objects"
+    )
+    expect_error(
+        tokens_subset(TRUE),
+        "tokens_subset\\(\\) only works on tokens objects"
+    )
     expect_error(
         tokens_compound(TRUE),
         "tokens_compound\\(\\) only works on tokens objects"
     )
+    expect_error(
+        tokens_split(TRUE),
+        "tokens_split\\(\\) only works on tokens objects"
+    )
     expect_error(
         tokens_keep(TRUE),
         "tokens_select\\(\\) only works on tokens objects"
@@ -274,6 +276,10 @@ test_that("test token default methods", {
         tokens_lookup(TRUE),
         "tokens_lookup\\(\\) only works on tokens objects"
     )
+    expect_error(
+        tokens_sample(TRUE),
+        "tokens_sample\\(\\) only works on tokens objects"
+    )
     expect_error(
         tokens_ngrams(TRUE),
         "tokens_ngrams\\(\\) only works on.*tokens objects"
@@ -306,6 +312,10 @@ test_that("test token default methods", {
         tokens_wordstem(TRUE),
         "tokens_wordstem\\(\\) only works on tokens objects"
     )
+    expect_error(
+        tokens_group(TRUE),
+        "tokens_group\\(\\) only works on tokens objects"
+    )
 })
 
 test_that("test new as.dfm methods", {
@@ -350,67 +360,10 @@ test_that("test new docnames<- methods", {
     )
 })
 
-test_that("test default textstat methods", {
+test_that("test docid methods", {
     expect_error(
-        textstat_dist(TRUE),
-        "textstat_dist\\(\\) only works on dfm objects"
-    )
-    expect_error(
-        textstat_frequency(TRUE),
-        "textstat_frequency\\(\\) only works on dfm objects"
-    )
-    expect_error(
-        textstat_keyness(TRUE),
-        "textstat_keyness\\(\\) only works on dfm objects"
-    )
-    expect_error(
-        textstat_lexdiv(TRUE),
-        "textstat_lexdiv\\(\\) only works on dfm, tokens objects"
-    )
-    expect_error(
-        textstat_readability(TRUE),
-        "textstat_readability\\(\\) only works on character, corpus objects"
-    )
-    expect_error(
-        textstat_simil(TRUE),
-        "textstat_simil\\(\\) only works on dfm objects"
-    )
-    expect_error(
-        textstat_collocations(TRUE),
-        "textstat_collocations\\(\\) only works on.*tokens objects"
-    )
-    expect_error(
-        textstat_entropy(tokens(data_char_sampletext)),
-        "textstat_entropy() only works on dfm objects.", fixed = TRUE
-    )
-})
-
-test_that("test default textplot methods", {
-    expect_error(
-        textplot_keyness(TRUE),
-        "textplot_keyness\\(\\) only works on keyness objects"
-    )
-    expect_error(
-        textplot_wordcloud(TRUE),
-        "textplot_wordcloud\\(\\) only works on dfm, keyness objects"
-    )
-    expect_error(
-        textplot_xray(TRUE),
-        "textplot_xray\\(\\) only works on kwic objects"
-    )
-})
-
-test_that("friendly_class_undefined_message for tokens_tortl()", {
-    expect_error(
-        tokens_tortl(data_dfm_lbgexample),
-        "tokens_tortl\\(\\) only works on.*tokens.*objects"
-    )
-})
-
-test_that("friendly_class_undefined_message for char_tortl()", {
-    expect_error(
-        char_tortl(data_dfm_lbgexample),
-        "char_tortl\\(\\) only works on.*character.*objects"
+        docid(0),
+        "docid() only works on corpus, dfm, tokens objects.", fixed = TRUE
     )
 })
 
@@ -428,12 +381,3 @@ test_that("friendly_class_undefined_message for char_select()", {
         fixed = TRUE
     )
 })
-
-test_that("friendly_class_undefined_message for textstat_summary()", {
-    expect_error(
-        textstat_summary(data_char_sampletext),
-        "textstat_summary() only works on corpus, dfm, tokens objects",
-        fixed = TRUE
-    )
-})
-
