@@ -1,5 +1,3 @@
-context("test tokens_compound")
-
 test_that("tokens_compound join tokens correctly", {
 
     txt <- c("a b c d e f g", "A B C D E F G", "A b C d E f G",
@@ -44,6 +42,7 @@ test_that("tokens_compound join tokens correctly", {
              c("aaa", "bbb", "ccc", "ddd", "eee", "fff", "ggg"),
              c("a_b", "b_c", "c_d", "d_e_e_f", "f_g"))
     )
+  
 })
 
 test_that("tokens_compound join a sequences of sequences", {
@@ -99,6 +98,27 @@ test_that("tokens_compound works with padded tokens", {
                  sort(c("a", "c_d", "f", "g")))
 })
 
+test_that("tokens_compound works with different concatenators", {
+  toks <- tokens(c(doc1 = "a b c d e f g"))
+  toks1 <- tokens_compound(toks, phrase("c d"), concatenator = "+")
+  expect_equal(sort(attr(toks1, "types")),
+               sort(c("a", "b", "c+d", "e", "f", "g")))
+  expect_equal(meta(toks1, field = "concatenator", type = "object"),
+               "+")
+  toks2 <- tokens_compound(toks, phrase("c d"), concatenator = "&&")
+  expect_equal(meta(toks2, field = "concatenator", type = "object"),
+               "&&")
+  expect_equal(sort(attr(toks2, "types")),
+               sort(c("a", "b", "c&&d", "e", "f", "g")))
+  toks3 <- tokens_compound(toks, phrase("c d"), concatenator = "")
+  expect_equal(meta(toks3, field = "concatenator", type = "object"),
+               "")
+  expect_equal(sort(attr(toks3, "types")),
+               sort(c("a", "b", "cd", "e", "f", "g")))
+  expect_error(tokens_compound(toks, phrase("c d"), concatenator = character()),
+               "The length of concatenator must be 1")
+})
+
 test_that("tokens_compound works as expected with nested tokens", {
 
     expect_equal(
@@ -129,42 +149,6 @@ test_that("tokens_compound works as expected with nested and overlapping tokens"
     )
 })
 
-test_that("tokens_compound works as expected with collocations", {
-
-    toks <- tokens("The new law included capital gains taxes and inheritance taxes.")
-    cols <- data.frame(collocation = c("the new", "capital gains", "gains taxes"), stringsAsFactors = FALSE)
-    class(cols) <- c("collocations", "data.frame")
-
-    expect_true(all(
-      c("The_new", "capital_gains", "gains_taxes") %in%
-      as.character(tokens_compound(toks, phrase(cols), join = FALSE))
-    ))
-
-    expect_true(all(
-      c("The_new", "capital_gains_taxes") %in%
-        as.character(tokens_compound(toks, phrase(cols), join = TRUE))
-    ))
-
-    expect_true(all(
-      c("The_new", "capital_gains_taxes") %in%
-        as.character(tokens_compound(toks, cols, case_insensitive = TRUE))
-    ))
-
-    expect_true(all(
-      c("capital_gains_taxes") %in%
-        as.character(tokens_compound(toks, cols, case_insensitive = FALSE))
-    ))
-
-    expect_equal(
-         tokens_compound(toks, cols),
-         tokens_compound(toks, phrase(cols))
-     )
-    expect_equal(
-        tokens_compound(toks, cols, join = TRUE),
-        tokens_compound(toks, phrase(cols), join = TRUE)
-    )
-})
-
 test_that("tokens_compound works as expected with dictionaries", {
     dict <- dictionary(list(taxcgt = c("capital gains tax*"), taxit = "inheritance tax*"))
     toks <- tokens("The new law included capital gains taxes and inheritance taxes.")
@@ -191,7 +175,7 @@ test_that("tokens_compound works as expected with dictionaries", {
 
 test_that("tokens_compound error when dfm is given, #1006", {
     toks <- tokens("a b c")
-    expect_error(tokens_compound(toks, dfm("b c d")))
+    expect_error(tokens_compound(toks, dfm(tokens("b c d"))))
 })
 
 test_that("tokens_compound window is working", {
@@ -242,9 +226,12 @@ test_that("tokens_compound window is working", {
   )
   expect_error(
     tokens_compound(toks, pat, join = FALSE, window = -1),
-    "window sizes cannot be negative"
+    "The value of window must be between 0 and Inf"
+  )
+  expect_error(
+    tokens_compound(toks, pat, join = FALSE, window = c(1, 1, 2)),
+    "The length of window must be between 1 and 2"
   )
-
   expect_equal(
     as.list(tokens_compound(tokens_remove(toks, "a", padding = TRUE), pat, join = TRUE, window = 1)),
     list(text1 = c("", "b_c_d_e", "f_g"))
